@@ -1,3 +1,4 @@
+import pickle
 import shutil
 from typing import Text
 
@@ -18,3 +19,11 @@ class Tts:
             with open(local_filename, 'wb') as f:
                 shutil.copyfileobj(r.raw, f)
         return local_filename
+
+    def convert_nd_array(self):
+        response = requests.post("http://137.184.57.49:8000/convert_nd_array", json={"region": self.region,
+                                                                            "text": self.text, "voice": self.voice})
+        return response.json()
+
+
+
